JBoss Tools SVN: r23457 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 18:37:56 -0400 (Thu, 15 Jul 2010)
New Revision: 23457
Modified:
trunk/build/publish.sh
Log:
move download-snippet.txt into logs/ folder
Modified: trunk/build/publish.sh
===================================================================
--- trunk/build/publish.sh 2010-07-15 22:35:19 UTC (rev 23456)
+++ trunk/build/publish.sh 2010-07-15 22:37:56 UTC (rev 23457)
@@ -91,10 +91,10 @@
-x \*docs\* -x \*reference\* -x \*releng\*
popd
-# generate HTML snippet for inclusion on jboss.org
+# generate HTML snippet, download-snippet.txt, for inclusion on jboss.org
if [[ ${RELEASE} == "Yes" ]]; then
- mkdir -p ${STAGINGDIR}
- ANT_PARAMS="-DZIPSUFFIX=${ZIPSUFFIX} -DJOB_NAME=${JOB_NAME} -Doutput.dir=${STAGINGDIR}"
+ mkdir -p ${STAGINGDIR}/logs
+ ANT_PARAMS="-DZIPSUFFIX=${ZIPSUFFIX} -DJOB_NAME=${JOB_NAME} -Doutput.dir=${STAGINGDIR}/logs"
if [[ -f ${WORKSPACE}/build/results/build.xml ]]; then
ant -f ${WORKSPACE}/build/results/build.xml ${ANT_PARAMS}
elif [[ -f ${WORKSPACE}/sources/build/results/build.xml ]]; then
15 years, 9 months
JBoss Tools SVN: r23456 - trunk/build/results.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 18:35:19 -0400 (Thu, 15 Jul 2010)
New Revision: 23456
Modified:
trunk/build/results/download-template.xml
Log:
add pi4soa to results html
Modified: trunk/build/results/download-template.xml
===================================================================
--- trunk/build/results/download-template.xml 2010-07-15 22:27:14 UTC (rev 23455)
+++ trunk/build/results/download-template.xml 2010-07-15 22:35:19 UTC (rev 23456)
@@ -95,6 +95,11 @@
<download os="All platforms" url="${modeshape-filename}" size="${modeshape-filesize} MB"/>
</project>
+<project name="Pi Calculus for SOA" version="${ZIPSUFFIX}">
+ <description>Provides Pi Calculus for SOA</description>
+ <download os="All platforms" url="${pi4soa-filename}" size="${pi4soa-filesize} MB"/>
+</project>
+
<project name="Portlet Tools" version="${ZIPSUFFIX}">
<description>For supporting JBoss Portal and JSR-286 portlets</description>
<download os="All platforms" url="${portlet-filename}" size="${portlet-filesize} MB"/>
@@ -150,4 +155,4 @@
<download os="All platforms" url="${sources-filename}" size="${sources-filesize} MB"/>
</project>
-</projects>
\ No newline at end of file
+</projects>
15 years, 9 months
JBoss Tools SVN: r23455 - trunk/build.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 18:27:14 -0400 (Thu, 15 Jul 2010)
New Revision: 23455
Modified:
trunk/build/publish.sh
Log:
move metadata files into a single file in logs/ dir; add SVN rev too
Modified: trunk/build/publish.sh
===================================================================
--- trunk/pom.xml 2010-07-15 22:03:24 UTC (rev 23453)
+++ trunk/pom.xml 2010-07-15 22:09:01 UTC (rev 23454)
@@ -44,6 +44,8 @@
<module>jbpm</module>
<!-- NOTE: To build drools, must first bootstrap with ant script: cd drools;
ant -q -->
+ <!-- IF YOU REMOVE A MODULE, be sure to also remove it from site/site.xml and build/aggregate/site/site.xml
+ or the build will break! -->
<!--module>drools</module-->
<module>site</module>
15 years, 9 months
JBoss Tools SVN: r23453 - in trunk: site and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 18:03:24 -0400 (Thu, 15 Jul 2010)
New Revision: 23453
Modified:
trunk/build/aggregate/site/site.xml
trunk/site/site.xml
Log:
remove drools because someone took it out of the main pom. again. GEEZ
Modified: trunk/build/aggregate/site/site.xml
===================================================================
--- trunk/build/aggregate/site/site.xml 2010-07-15 21:40:48 UTC (rev 23452)
+++ trunk/build/aggregate/site/site.xml 2010-07-15 22:03:24 UTC (rev 23453)
@@ -102,7 +102,8 @@
<category name="DataTools" />
<category name="GeneralTools" />
</feature>
- <feature url="features/org.drools.eclipse.feature_0.0.0.jar" id="org.drools.eclipse.feature" version="0.0.0">
+
+ <!-- <feature url="features/org.drools.eclipse.feature_0.0.0.jar" id="org.drools.eclipse.feature" version="0.0.0">
<category name="AllTools" />
<category name="SOATools" />
<category name="GeneralTools" />
@@ -117,7 +118,8 @@
<feature url="features/org.guvnor.tools.feature_0.0.0.jar" id="org.guvnor.tools.feature" version="0.0.0">
<category name="AllTools" />
<category name="SOATools" />
- </feature>
+ </feature> -->
+
<feature url="features/org.jboss.tools.project.examples.feature_0.0.0.jar"
id="org.jboss.tools.project.examples.feature"
version="0.0.0"
Modified: trunk/site/site.xml
===================================================================
--- trunk/site/site.xml 2010-07-15 21:40:48 UTC (rev 23452)
+++ trunk/site/site.xml 2010-07-15 22:03:24 UTC (rev 23453)
@@ -102,7 +102,8 @@
<category name="DataTools" />
<category name="GeneralTools" />
</feature>
- <feature url="features/org.drools.eclipse.feature_0.0.0.jar" id="org.drools.eclipse.feature" version="0.0.0">
+
+ <!--<feature url="features/org.drools.eclipse.feature_0.0.0.jar" id="org.drools.eclipse.feature" version="0.0.0">
<category name="AllTools" />
<category name="SOATools" />
<category name="GeneralTools" />
@@ -117,7 +118,8 @@
<feature url="features/org.guvnor.tools.feature_0.0.0.jar" id="org.guvnor.tools.feature" version="0.0.0">
<category name="AllTools" />
<category name="SOATools" />
- </feature>
+ </feature> -->
+
<feature url="features/org.jboss.tools.project.examples.feature_0.0.0.jar"
id="org.jboss.tools.project.examples.feature"
version="0.0.0"
15 years, 9 months
JBoss Tools SVN: r23452 - trunk/build/results.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 17:40:48 -0400 (Thu, 15 Jul 2010)
New Revision: 23452
Removed:
trunk/build/results/buildResults.xml
Modified:
trunk/build/results/
Log:
fix results snippet generator
Property changes on: trunk/build/results
___________________________________________________________________
Name: svn:ignore
+ download-snippet.txt
Deleted: trunk/build/results/buildResults.xml
===================================================================
--- trunk/build/results/buildResults.xml 2010-07-15 20:42:33 UTC (rev 23451)
+++ trunk/build/results/buildResults.xml 2010-07-15 21:40:48 UTC (rev 23452)
@@ -1,88 +0,0 @@
-<project default="build.results">
-
- <property name="ZIPSUFFIX" value="SNAPSHOT" />
-
- <condition property="WORKINGDIR" value="/home/hudson/static_build_env/jbds/tools/sources" else="${basedir}/../..">
- <available file="/home/hudson/static_build_env/jbds" type="dir" />
- </condition>
-
- <mkdir dir="${WORKINGDIR}" />
- <echo level="info">WORKINGDIR = ${WORKINGDIR}</echo>
-
- <condition property="COMMON_TOOLS" value="/home/hudson/static_build_env/jbds/tools">
- <available file="/home/hudson/static_build_env/jbds" type="dir" />
- </condition>
- <condition property="COMMON_TOOLS" value="${WORKINGDIR}/../tools" else="${java.io.tmpdir}">
- <available file="${WORKINGDIR}/../tools" type="dir" />
- </condition>
- <mkdir dir="${COMMON_TOOLS}" />
- <echo level="info">COMMON_TOOLS = ${COMMON_TOOLS}</echo>
-
- <target name="init">
- <ant antfile="${build.xml}" target="init" />
- <taskdef resource="net/sf/antcontrib/antlib.xml">
- <classpath>
- <pathelement location="${COMMON_TOOLS}/ant-contrib.jar" />
- </classpath>
- </taskdef>
- </target>
-
- <target name="build.results" depends="init">
- <!--
- 1. resolve variables in download-template.xml to produce download.xml
- 2. XSL transform download.xml to produce download.snippet.txt
- 3. manually copy the contents of this file into
- http://www.jboss.org/tools/downloads/stable.html or
- http://www.jboss.org/tools/downloads/dev.html, as applicable
- -->
-
- <!-- TODO: resolve variables for ZIPSUFFIX and *-filename, *-filesize, where * = component names -->
- <for param="UPDATEZIP">
- <path>
- <fileset dir="${WORKINGDIR}">
- <include name="*-Update-${ZIPSUFFIX}.zip" />
- <include name="*-Sources-${ZIPSUFFIX}.zip" />
- </fileset>
- </path>
- <sequential>
- <propertyregex property="COMPONENT"
- input="@{UPDATEZIP}"
- defaultvalue="@{UPDATEZIP}"
- regexp=".+/([^/]+\.zip)"
- replace="\1"
- casesensitive="false"
- override="true"
- />
- <propertyregex property="COMPONENT"
- input="@{COMPONENT}"
- defaultvalue="@{COMPONENT}"
- regexp="(.+)-(Update|Sources)-${ZIPSUFFIX}\.zip)"
- replace="\1"
- casesensitive="false"
- override="true"
- />
- <echo level="info">UPDATEZIP = @{UPDATEZIP}
-COMPONENT = ${COMPONENT}</echo>
- <var name="filesize" unset="true" />
- <get.size file="@{UPDATEZIP}" property="${COMPONENT}-filesize" />
- <propertycopy from="${repoFilename}.features" property="filesize" override="true" silent="true" />
- <echo level="info">filesize = ${filesize}</echo>
- <var name="filesize" unset="true" />
- </sequential>
- </for>
-
- <copy todir="${product.build.directory}" overwrite="true">
- <fileset file="download-template.xml" />
- <mapper type="merge" to="download.xml" />
- <filterchain>
- <expandproperties />
- </filterchain>
- </copy>
- <xslt in="${product.build.directory}/download.xml"
- out="${product.build.directory}/download-snippet.txt"
- style="download.xsl"
- />
- <delete file="${product.build.directory}/download.xml" />
- </target>
-
-</project>
15 years, 9 months
JBoss Tools SVN: r23451 - in workspace/dgolovin/experimental-build/bootstrap-build: tests and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: dgolovin
Date: 2010-07-15 16:42:33 -0400 (Thu, 15 Jul 2010)
New Revision: 23451
Modified:
workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml
workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml
Log:
Modified: workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml
===================================================================
--- workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml 2010-07-15 20:38:07 UTC (rev 23450)
+++ workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml 2010-07-15 20:42:33 UTC (rev 23451)
@@ -26,7 +26,7 @@
<id>suite2</id>
<phase>install</phase>
<goals>
- <goal>checkout</goal>
+ <goal>bootstrap</goal>
</goals>
</execution>
</executions>
Modified: workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml
===================================================================
--- workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml 2010-07-15 20:38:07 UTC (rev 23450)
+++ workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml 2010-07-15 20:42:33 UTC (rev 23451)
@@ -19,13 +19,14 @@
<configuration>
<checkoutDirectory>${basedir}/../../tests</checkoutDirectory>
<goals>install</goals>
+ <profiles>helios-no-target</profiles>
</configuration>
<executions>
<execution>
<id>suite2</id>
<phase>install</phase>
<goals>
- <goal>checkout</goal>
+ <goal>bootstrap</goal>
</goals>
</execution>
</executions>
15 years, 9 months
JBoss Tools SVN: r23450 - in workspace/dgolovin/experimental-build/bootstrap-build: tests and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: dgolovin
Date: 2010-07-15 16:38:07 -0400 (Thu, 15 Jul 2010)
New Revision: 23450
Modified:
workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml
workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml
Log:
change bootstrap to checkout
Modified: workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml
===================================================================
--- workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml 2010-07-15 20:32:44 UTC (rev 23449)
+++ workspace/dgolovin/experimental-build/bootstrap-build/build/pom.xml 2010-07-15 20:38:07 UTC (rev 23450)
@@ -26,7 +26,7 @@
<id>suite2</id>
<phase>install</phase>
<goals>
- <goal>bootstrap</goal>
+ <goal>checkout</goal>
</goals>
</execution>
</executions>
Modified: workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml
===================================================================
--- workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml 2010-07-15 20:32:44 UTC (rev 23449)
+++ workspace/dgolovin/experimental-build/bootstrap-build/tests/pom.xml 2010-07-15 20:38:07 UTC (rev 23450)
@@ -25,7 +25,7 @@
<id>suite2</id>
<phase>install</phase>
<goals>
- <goal>bootstrap</goal>
+ <goal>checkout</goal>
</goals>
</execution>
</executions>
15 years, 9 months
JBoss Tools SVN: r23449 - workspace/dgolovin/tests/features/org.jboss.tools.test.feature.
by jbosstools-commits@lists.jboss.org
Author: dgolovin
Date: 2010-07-15 16:32:44 -0400 (Thu, 15 Jul 2010)
New Revision: 23449
Modified:
workspace/dgolovin/tests/features/org.jboss.tools.test.feature/pom.xml
Log:
reference to parent pom fixed
Modified: workspace/dgolovin/tests/features/org.jboss.tools.test.feature/pom.xml
===================================================================
--- workspace/dgolovin/tests/features/org.jboss.tools.test.feature/pom.xml 2010-07-15 20:29:18 UTC (rev 23448)
+++ workspace/dgolovin/tests/features/org.jboss.tools.test.feature/pom.xml 2010-07-15 20:32:44 UTC (rev 23449)
@@ -2,7 +2,7 @@
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd" xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
<modelVersion>4.0.0</modelVersion>
<parent>
- <relativePath>../../../build/build/parent-pom.xml</relativePath>
+ <relativePath>../../../build/parent-pom.xml</relativePath>
<groupId>org.jboss.tools</groupId>
<artifactId>org.jboss.tools.parent.pom</artifactId>
<version>0.0.1-SNAPSHOT</version>
15 years, 9 months
--- trunk/build/publish.sh 2010-07-15 22:09:01 UTC (rev 23454)
+++ trunk/build/publish.sh 2010-07-15 22:27:14 UTC (rev 23455)
@@ -43,11 +43,13 @@
if [[ $z != "" ]] && [[ -f $z ]] ; then
#echo "$z ..."
- # note the job name, build number, and build ID of the latest snapshot zip
- mkdir -p ${STAGINGDIR}/meta
- echo "JOB_NAME = ${JOB_NAME}" > ${STAGINGDIR}/meta/JOB_NAME.txt
- echo "BUILD_NUMBER = ${BUILD_NUMBER}" > ${STAGINGDIR}/meta/BUILD_NUMBER.txt
- echo "BUILD_ID = ${BUILD_ID}" > ${STAGINGDIR}/meta/BUILD_ID.txt
+ # note the job name, build number, SVN rev, and build ID of the latest snapshot zip
+ mkdir -p ${STAGINGDIR}/logs
+ METAFILE="build${BUILD_NUMBER}_rev${SVN_REVISION}_${BUILD_ID}.txt"
+ echo "JOB_NAME = ${JOB_NAME}" > ${STAGINGDIR}/logs/${METAFILE}
+ echo "BUILD_NUMBER = ${BUILD_NUMBER}" > ${STAGINGDIR}/logs/${METAFILE}
+ echo "SVN_REVISION = ${SVN_REVISION}" > ${STAGINGDIR}/logs/${METAFILE}
+ echo "BUILD_ID = ${BUILD_ID}" > ${STAGINGDIR}/logs/${METAFILE}
# unzip into workspace for publishing as unpacked site
mkdir -p ${STAGINGDIR}/all/repo
15 years, 9 months
JBoss Tools SVN: r23454 - trunk.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2010-07-15 18:09:01 -0400 (Thu, 15 Jul 2010)
New Revision: 23454
Modified:
trunk/pom.xml
Log:
add comment in pom.xml re: breaking build by removing a module on which the update site depends
Modified: trunk/pom.xml
===================================================================